@@ -1,6 +1,5 @@
 context("Individual coordinate functions cc_*")
 
-require(sp)
 require(rnaturalearth)
 require(dplyr)
 
@@ -10,29 +9,24 @@ lon <- runif(250, min = 42, max = 51)
 set.seed(2)
 lat <- runif(250, min = -26, max = -11)
 exmpl <- data.frame(species = sample(letters[-1], size = 250, replace = TRUE),
-                    decimallongitude = lon,
-                    decimallatitude = lat,
+                    decimalLongitude = lon,
+                    decimalLatitude = lat,
                     countrycode = "RUS")
 
-
-range_species_A <- Polygon(cbind(c(-180,-180, 180, 180,-180),
-                                 c(-90,90,90,-90,-90)))
-range_A <- Polygons(list(range_species_A), ID = c("a"))
-range <- SpatialPolygons(list(range_A))
-
-df_miss <- data.frame(species = c("a"), row.names = c("a"))
-df <- data.frame(species = c("e"), row.names = c("a"))
-range_emp <- SpatialPolygonsDataFrame(range, data = as.data.frame(df_miss))
-range <- SpatialPolygonsDataFrame(range, data = as.data.frame(df))
+range_species_A <- cbind(cbind(c(-180,-180, 180, 180,-180),
+                               c(-90,90,90,-90,-90)))
+range <- terra::vect(range_species_A, "polygons")
+range$binomial <- "a"
+terra::crs(range) <- '+proj=longlat +datum=WGS84 +no_defs'
 
 # run tests
 ## cc_cap
 test_that("cc_cap works", {
   expect_equal(sum(cc_cap(x = exmpl, value = "flagged")), 250)
   expect_equal(sum(cc_cap(x = exmpl, value = "flagged"), verbose = FALSE), 250)
-  expect_equal(sum(cc_cap(x = exmpl, buffer = 10000000, value = "flagged")), 0)
-  expect_equal(sum(cc_cap(x = exmpl, buffer = 10000000, 
-                          value = "flagged", verify = T)), 0)
+  expect_equal(sum(cc_cap(x = exmpl, buffer = 1000000, value = "flagged")), 0)
+  expect_equal(sum(cc_cap(x = exmpl, buffer = 1000000, 
+                          value = "flagged", verify = TRUE)), 0)
   
   expect_error(cc_cap(x = exmpl, lon = "longitude", value = "flagged"), 
                "undefined columns selected")
@@ -42,7 +36,7 @@ test_that("cc_cap works", {
 test_that("cc_cen works", {
   expect_equal(sum(cc_cen(x = exmpl, value = "flagged")), 250)
   expect_equal(sum(cc_cen(x = exmpl, value = "flagged"), verbose = FALSE), 250)
-  expect_equal(sum(cc_cen(x = exmpl, buffer = 10000000, value = "flagged")), 0)
+  expect_equal(sum(cc_cen(x = exmpl, buffer = 900000, value = "flagged")), 0)
   
   expect_error(cc_cen(x = exmpl, lon = "longitude", value = "flagged"), 
                "undefined columns selected")
@@ -51,14 +45,14 @@ test_that("cc_cen works", {
 ## cc_coun
 test_that("cc_coun works", {
 skip_on_cran()
-  library(rnaturalearthdata)
-  exmpl2 <-  data.frame(decimallatitude = c(51.5, -10), 
-                        decimallongitude = c(8, 40),
+  exmpl2 <-  data.frame(decimalLatitude = c(51.5, -10), 
+                        decimalLongitude = c(8, 40),
                         countrycode = c("DEU", "DEU"))
   
-  cust_ref1 <- rnaturalearth::ne_countries(scale = "small")
+  cust_ref1 <- terra::vect(rnaturalearth::ne_countries(scale = "small",
+                                                       returnclass = "sf"))
+  cust_ref1 <- terra::project(cust_ref1, '+proj=longlat +datum=WGS84 +no_defs')
   cust_ref2 <- cust_ref1
-  names(cust_ref2)[45] <- "iso_a3_eh"
 
   expect_is(cc_coun(exmpl, value = "flagged"), "logical")
   expect_is(cc_coun(exmpl, value = "clean"), "data.frame")
@@ -66,11 +60,14 @@ skip_on_cran()
   #customized references
   expect_equal(nrow(cc_coun(x = exmpl2)), 1)
   expect_error(cc_coun(x = exmpl2, ref = cust_ref1, ref_col = "test"))
-  expect_error(cc_coun(x = exmpl2, ref = cust_ref2))
-  expect_equal(nrow(cc_coun(x = exmpl2, ref = cust_ref2, ref_col = "iso_a3_eh")), 1)
+  expect_equal(nrow(cc_coun(
+    x = exmpl2, ref = cust_ref2, ref_col = "iso_a3_eh"
+  )), 1)
   
   
-  expect_equal(sum(cc_coun(x = exmpl, value = "flagged", ref = cust_ref1)), 0)
+  expect_equal(sum(
+    cc_coun(x = exmpl, value = "flagged", ref = cust_ref1)
+  ), 0)
   expect_equal(sum(cc_coun(x = exmpl, value = "flagged")), 0)
   
   expect_error(cc_coun(x = exmpl, lon = "longitude", value = "flagged"), 
@@ -82,8 +79,8 @@ skip_on_cran()
 test_that("cc_gbif works", {
   
   t.gbif <- rbind(exmpl, data.frame(species = c("a", "a", "bia"), 
-                                    decimallongitude = c(12.58, 12.585, 12.58),
-                                    decimallatitude = c(55.67, 55.676, 55.67),
+                                    decimalLongitude = c(12.58, 12.585, 12.58),
+                                    decimalLatitude = c(55.67, 55.676, 55.67),
                                     countrycode = "RUS"))
   
   expect_is(cc_gbif(exmpl, value = "flagged"), "logical")
@@ -104,18 +101,18 @@ test_that("cc_gbif works", {
 test_that("cc_inst works", {
 skip_on_cran()
   t.inst <- rbind(exmpl, data.frame(species = c("a", "a", "bia"), 
-                                    decimallongitude = c(12.58, 12.585, 12.58),
-                                    decimallatitude = c(55.67, 55.676, 55.67),
+                                    decimalLongitude = c(12.58, 12.585, 12.58),
+                                    decimalLatitude = c(55.67, 55.676, 55.67),
                                     countrycode = "RUS"))
-  
-  expect_is(cc_inst(t.inst, value = "flagged"), "logical")
+  resA <- cc_inst(t.inst, value = "flagged")
+  expect_is(resA, "logical")
   expect_is(cc_inst(t.inst, value = "clean"), "data.frame")
   
-  expect_equal(sum(cc_inst(x = t.inst, value = "flagged")), 253)
-  expect_equal(sum(cc_inst(x = t.inst, value = "flagged", geod = FALSE)), 0)
+  expect_equal(sum(resA), 253)
+  expect_equal(sum(cc_inst(x = t.inst, value = "flagged", geod = FALSE)), 253)
   
   expect_equal(sum(cc_inst(x = t.inst, value = "flagged", 
-                           geod = FALSE, buffer = 0.01)), 251)
+                           geod = FALSE, buffer = 0.01)), 253)
   
   expect_equal(sum(cc_inst(x = t.inst, 
                            value = "flagged",
@@ -126,7 +123,7 @@ skip_on_cran()
                            verify = T, 
                            geod = FALSE, 
                            buffer = 100)), 
-               252)
+               253)
   
   expect_error(cc_inst(x = exmpl, lon = "longitude", value = "flagged"), 
                "undefined columns selected")
@@ -136,34 +133,45 @@ skip_on_cran()
 # cc_iucn
 test_that("cc_iucn works", {
 skip_on_cran()
-  expect_equal(sum(cc_iucn(x = exmpl, range = range_emp, value = "flagged")),
+  res_iucn <- expect_warning(cc_iucn(x = exmpl, range = range,
+                      value = "flagged",
+                      verbose = FALSE))
+  expect_equal(sum(res_iucn),
                nrow(exmpl))
-  expect_true(sum(cc_iucn(x = exmpl, range = range, value = "flagged")) > 0)
+  res_iucn2 <-
+    expect_warning(cc_iucn(x = exmpl, range = range, value = "flagged"))
+  expect_true(sum(res_iucn2) > 0)
 })
 
-# cc_outl
+# cc_outl (ADD SUPRESS WARNINGS)
 test_that("cc_outl works", {
-skip_on_cran()
-  expect_equal(sum(cc_outl(x = exmpl, value = "flagged")), 249)
-  expect_equal(sum(cc_outl(x = exmpl, value = "flagged"), verbose = FALSE), 249)
-  expect_equal(sum(cc_outl(x = exmpl, value = "flagged", mltpl = 0.1)), 200)
-  expect_equal(sum(cc_outl(x = exmpl, value = "flagged", mltpl = 1000)), 250)
+skip_on_cran() 
+  
+  expect_equal(sum(cc_outl(
+    x = exmpl, value = "flagged", min_occs = 5
+  )), 249)
+  expect_equal(sum(
+    cc_outl(x = exmpl, value = "flagged", verbose = FALSE, min_occs = 5)
+  ), 249)
+  expect_equal(sum(
+    cc_outl(x = exmpl, value = "flagged", mltpl = 0.1, min_occs = 5)
+  ), 197)
+  expect_equal(sum(
+    cc_outl(x = exmpl, value = "flagged", mltpl = 1000, min_occs = 5)
+  ), 250)
   
   
-  if(class(try(rgbif::occ_count(country = "DEU"))) == "try-error"){
-    expect_equal(sum(cc_outl(x = exmpl, value = "flagged", 
-                             sampling_thresh = 0.2, mltpl = 0.1)), 200) 
-  }else{
-    expect_equal(sum(cc_outl(x = exmpl, value = "flagged", 
-                             sampling_thresh = 0.2, mltpl = 0.1)), 242) 
-  }
+  expect_equal(sum(cc_outl(x = exmpl, value = "flagged", 
+                             sampling_thresh = 0.2, mltpl = 0.1, 
+                             min_occs = 5)), 197) 
   expect_equal(sum(cc_outl(x = exmpl, 
                            value = "flagged", 
                            method = "distance", 
-                           tdi = .001)), 11)
+                           tdi = .001, min_occs = 5)), 0)
   expect_equal(sum(cc_outl(x = exmpl, 
                            value = "flagged", 
-                           method = "distance", tdi = 10000)), 250)
+                           method = "distance", tdi = 10000, 
+                           min_occs = 5)), 250)
 
   expect_error(cc_dupl(x = exmpl, 
                        lon = "longitude", 
@@ -176,12 +184,13 @@ test_that("cc_sea works", {
   skip_on_cran()
   skip_if_offline()
   
-  cust_ref1 <- cust_ref2 <- rnaturalearth::ne_download(scale = 
+  cust_ref1 <- cust_ref2 <- terra::vect(rnaturalearth::ne_download(scale = 
                                                          "medium", 
                                                        type = 'land', 
-                                                       category = "physical")
-
-  proj4string(cust_ref2) <- ""
+                                                       category = "physical", 
+                                                       returnclass = "sf"))
+  # terra::project(cust_ref2, "")
+  # proj4string(cust_ref2) <- ""
 
   expect_is(cc_sea(exmpl, value = "flagged", ref = cust_ref1), "logical")
   expect_is(cc_sea(exmpl, value = "clean", ref = cust_ref1), "data.frame")
@@ -204,12 +213,13 @@ test_that("cc_urb works", {
   skip_on_cran()
   skip_if_offline()
   
-  cust_ref <- rnaturalearth::ne_download(scale = "medium", type = 'urban_areas')
-  
+  cust_ref <-
+    terra::vect(rnaturalearth::ne_download(scale = "medium", type = 'urban_areas',
+                                           returnclass = "sf"))
+  xy <- terra::crds(cust_ref)[sample(1:terra::ncell(cust_ref), 200), ]
   city_exmpl <- data.frame(species = letters[1:10], 
-                           coordinates(sp::spsample(cust_ref, n = 200, 
-                                                    type = "random")))
-  names(city_exmpl) <- c("species", "decimallongitude", "decimallatitude")
+                           xy )
+  names(city_exmpl) <- c("species", "decimalLongitude", "decimalLatitude")
   city_exmpl <- dplyr::bind_rows(exmpl, city_exmpl)
   
   expect_is(cc_urb(city_exmpl, value = "flagged"), "logical")
@@ -224,8 +234,8 @@ test_that("cc_urb works", {
 
 #extend input data
 exmpl <- rbind(exmpl, data.frame(species = rep("a", 50), 
-                                 decimallongitude = rep( 50.25, 50), 
-                                 decimallatitude = rep(55.77), 
+                                 decimalLongitude = rep( 50.25, 50), 
+                                 decimalLatitude = rep(55.77), 
                                  countrycode = "RUS"))
 
 exmpl <- data.frame(exmpl, 
@@ -248,3 +258,14 @@ skip_on_cran()
                        value = "flagged"), 
                "undefined columns selected")
 })
+
+
+
+test_that("cc_aohi works", {
+  skip_on_cran()
+  
+  expect_equal(sum(cc_aohi(x = exmpl, value = "flagged")), 300)
+  expect_equal(sum(cc_aohi(x = exmpl, value = "flagged", 
+                           buffer = 10000000)), 0)
+})
+
